package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````Z"(```````!``````````*BA````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````#29````````-)D`````````
M``$```````$````&````")L````````(FP$```````B;`0``````>`4`````
M``"@%0```````````0```````@````8````8FP```````!B;`0``````&)L!
M``````!0`@```````%`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````8)(```````!@D@```````&"2````````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!`````B;````````")L!```````(FP$`
M`````/@$````````^`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````$`````$```!'3E4```````,````'``````````0`
M```4`````P```$=.50#&09)KY567JC'M,TU<]$1(*95^!1$```!.````!```
M``@````A$!``!<`$A"@"$`&`AD"`@BD`!`D@!(F(H!A%N@0""$X```!/````
M4P```%@```!9````8````&$```!B````9````&4`````````9P```&@```!I
M````:P```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_
MY`ZXC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#
MUF>OS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)
M```````````````````````````````````````````#``L`B!P`````````
M```````````````#`!8``*`!``````````````````8#```2````````````
M`````````````!\#```2`````````````````````````*8"```2````````
M`````````````````-,"```2`````````````````````````"<#```2````
M`````````````````````'H"```2`````````````````````````!$````@
M`````````````````````````+0"```2`````````````````````````'$"
M```2`````````````````````````-H"```B````````````````````````
M`)\"```2`````````````````````````(@"```2````````````````````
M`````+0````2`````````````````````````#4#```1````````````````
M`````````(,!```2`````````````````````````.D"```2````````````
M`````````````(0````2``````````````````````````P!```2````````
M`````````````````%,"```2`````````````````````````$4"```2````
M`````````````````````*H!```2``````````````````````````$!```1
M`````````````````````````#`"```2`````````````````````````&<!
M```2`````````````````````````.,````1````````````````````````
M`#4!```2`````````````````````````%,#```2````````````````````
M``````T#```2`````````````````````````)@"```2````````````````
M`````````,(````2`````````````````````````+$!```2````````````
M`````````````!,"```2`````````````````````````)X!```2````````
M`````````````````.$!```2`````````````````````````)`"```2````
M`````````````````````,P"```2`````````````````````````'\"```2
M`````````````````````````$(#```2`````````````````````````/4!
M```2`````````````````````````$,!```2````````````````````````
M`"T````@`````````````````````````(\#```1````````````````````
M`````#P#```2`````````````````````````,4"```2````````````````
M`````````&0````2`````````````````````````&$#```2````````````
M`````````````&`"```2`````````````````````````/`#```2````````
M`````````````````"H"```2`````````````````````````),````2````
M`````````````````````)\````2`````````````````````````%P!```2
M`````````````````````````/L"```2`````````````````````````"(!
M```2`````````````````````````!$!```2````````````````````````
M`%8````2`````````````````````````&<"```2````````````````````
M`````!8!```2`````````````````````````),!```2````````````````
M`````````/`````2`````````````````````````#X"```2````````````
M`````````````'4!```2`````````````````````````',````2````````
M`````````````````!L"```2`````````````````````````*T"```2````
M`````````````````````&\#```1`````````````````````````'$#```1
M`````````````````````````/L!```2`````````````````````````-0`
M```2`````````````````````````%,!```2````````````````````````
M`+X"```2`````````````````````````#P````@````````````````````
M``````("```2`````````````````````````$P"```2````````````````
M`````````%L#```2``````````````````````````T$```0`!<`J+`!````
M`````````````/D#```2``T`\%````````"``````````+D#```2``X`!%(`
M`````````````````#$$```2``T`*$0```````#8"````````!H#```2``T`
MP"`````````H`@```````+\#```2``T`4#T````````$`````````-`#```0
M`!<`@*`!`````````````````+@$```2``T`6#T````````,`@```````+($
M```2``L`B!P``````````````````.4$```2``T``$T```````#L`P``````
M`*0$```0`!<`@*`!`````````````````!@$```2``T`:#\````````L````
M`````$L$```1``\`&%(````````$`````````(H$```0`!<`J+`!````````
M`````````(\$```0`!<`J+`!`````````````````+`$```2``T`Z#L`````
M```X`````````,4$```2``T`.$,```````#L`````````-<$```2``T`@$(`
M``````"(`````````#X$```0`!8``*`!`````````````````"4$```2``T`
MF#\````````<`0````````4$```0`!8`@*`!`````````````````(`$```1
M`!8`>*`!```````(`````````*\#```2``T``%(````````$`````````'`$
M```2``T`@%$```````"``````````$0$```2``T`Z"(`````````````````
M`$`$```@`!8``*`!`````````````````-X#```2``T`"$,````````L````
M``````P$```0`!<`J+`!`````````````````%H$```2``T`>#P```````#8
M`````````)<$```2``T`N$````````#$`0````````!L:6)P97)L+G-O+C4N
M,C@`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`
M4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP
M`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M
M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G
M=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!0
M97)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`&QI8F1L+G-O+C(`;&EB;2YS;RXV
M`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P
M96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`
M<FUD:7(`7U]S=')N8W!Y7V-H:P!S=')C:'(`9V5T<&ED`'5N;&EN:P!?7VUE
M;6-P>5]C:&L`<W1R8VUP`')E861D:7(V-`!R96%D;&EN:P!E>&ET`&-L;W-E
M9&ER`&]P96YD:7(`<F5A;&QO8P!M96US970`9V5T=6ED`'-T<G1O:P!M96UC
M:'(`7U]X<W1A=#8T`'-T<G-T<@!A8V-E<W,`<W1R9'5P`'-T<FQE;@!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7VQX<W1A=#8T`&UE;6-P
M>0!?7VQI8F-?<W1A<G1?;6%I;@!M96UM;W9E`%]?<W!R:6YT9E]C:&L`<W1D
M97)R`&%B;W)T`%]?<W1A8VM?8VAK7V9A:6P`<W1R;F-M<`!M:V1I<@!?7V9P
M<FEN=&9?8VAK`%]?96YV:7)O;@!L9"UL:6YU>"UA87)C:#8T+G-O+C$`7U]S
M=&%C:U]C:&M?9W5A<F0`;&EB8W)Y<'0N<V\N,0!?7VQI8F-?8W-U7V9I;FD`
M<&%R7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P
M87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S
M=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L
M:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?
M96YV`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U
M<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"3T]4
M`$=,24)#7S(N,3<``````````@`"``(``@`"``(````"``(``@`"``(````"
M`````@```````@`"``(````"``````````(``@`"```````#`````P`"``(`
M`@`"``,```````0``@`"`````@`"``(``@`````````"`````@````(`````
M`````@```````P`"``(``@`#```````"`````P`"``(``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$````!``$`>0,``!`````@````EY&6!@``!`#[!`````````$``0#1`0``
M$````"````"7D98&```#`/L$`````````0`!`"`"```0`````````)>1E@8`
M``(`^P0````````(FP$```````,$````````Z",````````0FP$```````,$
M````````H",```````"(GP$```````,$`````````%(```````#0GP$`````
M``,$````````@%$```````#@GP$```````,$````````P"`````````(H`$`
M``````,$````````"*`!```````8H`$```````,$````````(%8````````@
MH`$```````,$````````6%(````````PH`$```````,$````````N%,`````
M```XH`$```````,$`````````%8```````!`H`$```````,$````````"%8`
M``````!(H`$```````,$````````$%8```````!0H`$```````,$````````
M&%8```````!@H`$```````,$````````Z%4```````!HH`$```````,$````
M````\%4```````!XH`$```````,$````````*%8```````"0GP$```````$$
M```)``````````````"8GP$```````$$```,``````````````"@GP$`````
M``$$```0``````````````"HGP$```````$$```1``````````````"PGP$`
M``````$$```8``````````````"XGP$```````$$```;``````````````#`
MGP$```````$$```K``````````````#(GP$```````$$```L````````````
M``#8GP$```````$$```X``````````````#HGP$```````$$``!!````````
M``````#PGP$```````$$``!%``````````````#XGP$```````$$``!*````
M``````````"`G0$```````($```#``````````````"(G0$```````($```$
M``````````````"0G0$```````($```%``````````````"8G0$```````($
M```&``````````````"@G0$```````($```'``````````````"HG0$`````
M``($```(``````````````"PG0$```````($```*``````````````"XG0$`
M``````($```+``````````````#`G0$```````($```,``````````````#(
MG0$```````($```-``````````````#0G0$```````($```.````````````
M``#8G0$```````($```/``````````````#@G0$```````($```2````````
M``````#HG0$```````($```3``````````````#PG0$```````($```4````
M``````````#XG0$```````($```5````````````````G@$```````($```6
M```````````````(G@$```````($```7```````````````0G@$```````($
M```9```````````````8G@$```````($```:```````````````@G@$`````
M``($```<```````````````HG@$```````($```=```````````````PG@$`
M``````($```>```````````````XG@$```````($```?``````````````!`
MG@$```````($```@``````````````!(G@$```````($```A````````````
M``!0G@$```````($```B``````````````!8G@$```````($```C````````
M``````!@G@$```````($```D``````````````!HG@$```````($```E````
M``````````!PG@$```````($```F``````````````!XG@$```````($```G
M``````````````"`G@$```````($```H``````````````"(G@$```````($
M```I``````````````"0G@$```````($```J``````````````"8G@$`````
M``($```K``````````````"@G@$```````($```M``````````````"HG@$`
M``````($```N``````````````"PG@$```````($```O``````````````"X
MG@$```````($```P``````````````#`G@$```````($```Q````````````
M``#(G@$```````($```R``````````````#0G@$```````($```S````````
M``````#8G@$```````($```T``````````````#@G@$```````($```U````
M``````````#HG@$```````($```V``````````````#PG@$```````($```W
M``````````````#XG@$```````($```Y````````````````GP$```````($
M```Z```````````````(GP$```````($```[```````````````0GP$`````
M``($```\```````````````8GP$```````($```]```````````````@GP$`
M``````($```^```````````````HGP$```````($```_```````````````P
MGP$```````($``!````````````````XGP$```````($``!"````````````
M``!`GP$```````($``!#``````````````!(GP$```````($``!&````````
M``````!0GP$```````($``!'``````````````!8GP$```````($``!(````
M``````````!@GP$```````($``!)``````````````!HGP$```````($``!+
M``````````````!PGP$```````($``!,``````````````!XGP$```````($
M``!-``````````````#]>[^I_0,`D:0!`)3]>\&HP`-?U@````#P>[^IT```
MD!&^1OD0XC61(`(?UA\@`]4?(`/5'R`#U=```)`1PD;Y$`(VD2`"'];0``"0
M$<9&^1`B-I$@`A_6T```D!'*1OD00C:1(`(?UM```)`1SD;Y$&(VD2`"'];0
M``"0$=)&^1""-I$@`A_6T```D!'61OD0HC:1(`(?UM```)`1VD;Y$,(VD2`"
M'];0``"0$=Y&^1#B-I$@`A_6T```D!'B1OD0`C>1(`(?UM```)`1YD;Y$"(W
MD2`"'];0``"0$>I&^1!"-Y$@`A_6T```D!'N1OD08C>1(`(?UM```)`1\D;Y
M$((WD2`"'];0``"0$?9&^1"B-Y$@`A_6T```D!'Z1OD0PC>1(`(?UM```)`1
M_D;Y$.(WD2`"'];0``"0$0)'^1`".)$@`A_6T```D!$&1_D0(CB1(`(?UM``
M`)`1"D?Y$$(XD2`"'];0``"0$0Y'^1!B.)$@`A_6T```D!$21_D0@CB1(`(?
MUM```)`1%D?Y$*(XD2`"'];0``"0$1I'^1#".)$@`A_6T```D!$>1_D0XCB1
M(`(?UM```)`1(D?Y$`(YD2`"'];0``"0$29'^1`B.9$@`A_6T```D!$J1_D0
M0CF1(`(?UM```)`1+D?Y$&(YD2`"'];0``"0$3)'^1"".9$@`A_6T```D!$V
M1_D0HCF1(`(?UM```)`1.D?Y$,(YD2`"'];0``"0$3Y'^1#B.9$@`A_6T```
MD!%"1_D0`CJ1(`(?UM```)`11D?Y$"(ZD2`"'];0``"0$4I'^1!".I$@`A_6
MT```D!%.1_D08CJ1(`(?UM```)`14D?Y$((ZD2`"'];0``"0$59'^1"B.I$@
M`A_6T```D!%:1_D0PCJ1(`(?UM```)`17D?Y$.(ZD2`"'];0``"0$6)'^1`"
M.Y$@`A_6T```D!%F1_D0(CN1(`(?UM```)`1:D?Y$$([D2`"'];0``"0$6Y'
M^1!B.Y$@`A_6T```D!%R1_D0@CN1(`(?UM```)`1=D?Y$*([D2`"'];0``"0
M$7I'^1#".Y$@`A_6T```D!%^1_D0XCN1(`(?UM```)`1@D?Y$`(\D2`"'];0
M``"0$89'^1`B/)$@`A_6T```D!&*1_D00CR1(`(?UM```)`1CD?Y$&(\D2`"
M']:P``#P$9)'^1""/)$@`A_6L```\!&61_D0HCR1(`(?UK```/`1FD?Y$,(\
MD2`"']:P``#P$9Y'^1#B/)$@`A_6L```\!&B1_D0`CV1(`(?UK```/`1ID?Y
M$"(]D2`"']:P``#P$:I'^1!"/9$@`A_6L```\!&N1_D08CV1(`(?UK```/`1
MLD?Y$((]D2`"']:P``#P$;9'^1"B/9$@`A_6L```\!&Z1_D0PCV1(`(?UK``
M`/`1OD?Y$.(]D2`"'];]>[FI_0,`D?-3`:FT``#P@^9'^?5;`JED`$#YY#<`
M^00`@-+BAP2IXB,!D>%#`9'@7P"YX',!D8K__Y>@``#PH@``\`#T1_E"[$?Y
MX0,"JA@,`)2@``#P`-Q'^0``0#E`"@`TTP``D+4``/#W&P#YM=I'^:`"0+E2
M__^7`6A2.2$`'S(!:!(YH`)`N4W__Y<":%(YX5]`N4(``#(":!(Y(10`$2!\
M?9-"__^7Y2M`^6(B`I'!``"0A@"`4@0``/`#``#P)SQ`^81@%Y&A`$#Y8X`7
MD0$0`*DA`(#21@0`N>8`@))`!`#YXE]`N0<,`:E?!`!Q#0$`5",0`!&D>&'X
MP\PCBR$$`)%?``%K!&@C^$S__U1%$``1=B("D>,#`*I"#``1!<PEBP$``+#`
M#D#Y(8`PD;^`'_@$`(#2??__E_4#`"K`!``T=B("D?>3`9'`#D#Y]_[_EP``
M`/#A`Q>J`"`-D:D$`)0@!`"T<R("D6`.0/G;_O^78O__EY3F1_G@`Q4JXC=`
M^8$"0/E!``'*800`M?-30:GU6T*I]QM`^?U[QZC``U_6^O[_E],``)!B(@*1
M0`P`^?<;`/D@`P"TM0``\,/^_Y>@VD?Y``!`N?S^_Y<?Q"@YIO__%\`.0/ET
M__^7]0,`*MC__Q?`"D#Y8```M(\+`)3=__\7X0,7J@```/``0`N1@`0`E,`*
M`/G@^O^TAPL`E-7__Q?Y_O^7(`"`4HO^_Y<=`(#2'@"`TN4#`*KA`T#YXB,`
MD>8#`)&@``#P`/!'^:,``/!CZ$?YI```\(3$1_G"_O^7^?[_EZ```/``X$?Y
M0```M/'^_Q?``U_6'R`#U<```)````*1P0``D"$``I$_``#KH```5*$``/`A
MR$?Y00``M"``'];``U_6'R`#U<```)````*1P0``D"$``I$A``#+(?Q#DR'\
M08LA_$&3H0``M*(``/!"_$?Y0@``M$``'];``U_6_7N^J?T#`)'S"P#YTP``
MD&`"0CE``0`UH```\`#,1_F```"TP```D``$0/E=_O^7VO__ER``@%)@`@(Y
M\PM`^?U[PJC``U_6X/__%Q\@`]7_@PK1J```\.)C`)$%X`"1">`!D>0#`JK]
M>P"I_0,`D0'E1_DC`$#YXT\!^0,`@-*A`$"YA$``D:.$0/@A",!:@0`?^+\`
M">MA_&#39_QHT^<<>)(FW'C3(1P(4\8<<)+CX$.J(0`&JB$``ZJ!@!_X`?[_
M5$4`")%!`$#Y0B``D4,$0/E$'$#Y8P`!RD$P0/DA``3*(0`#RB/\7]-A!`&J
M(7Q`DD$\`/E?``7K8?[_5`400*DC,X_2!AQ!J4-0J_+KLT&I(G2=TJK\6].M
M_$+32A4%JJUY!:KA``;*(MNM\B$`!(HA``?*:P$#BRI`*HN!_$+3(7@$JDH!
M"XL)$$#Y+GQ`DLL!!LJ,`0.+2@$)"VL!!8IK`0;*(0`-RD_]6]-K`0>+[Q4*
MJFL!#(OK`0L+3_U"TR$`"HKJ>0JJ[+]"J2$`#LIP_5O3(0`&BQ`6"ZJ,`0.+
M[P$#BR$`#(NL`0K*`0(!"XP!"XJP?4"2;?U"TXP!$,JM>0NJC`$.BR[\6].,
M`0^+2P$-RLX5`:I*?4"2[Q]`^<X!#`MK`0&*+/Q"TVL!"LKO`0.+:P$0B]#]
M6].,>0&J$!8.JFL!#XNA`0S*"P(+"]#]0M,A``Z*#GH.JN]#1*FM?4"2(0`-
MRB$`"HOJ`0.+;_U;TR$`"HN*`0[*[Q4+JHQ]0))*`0N*[P$!"TH!#,IA_4+3
M$`(#BRMX"ZI*`0V+P0$+RDH!$(O.?4"2\"M`^>W]6],A``^*K14/JB$`#LKQ
M_4+3K0$*"R]Z#ZH*`@.+(0`,BR$`"HMJ`0_*L/U;TVM]0))*`0V*$!8-JDH!
M"\H0`@$+2@$.B[']0M/ANT6I+7H-J@S^6],1_D+3C!40JB$``XM*`0&+X0$-
MRB$`$(KO?4"2(0`/RHP!"@LP>A"JR@$#BR$`"XN._5O3(0`*BZH!$,I*`0R*
MK7U`DLX5#*I*`0W*S@$!"TH!#XOAOT:ID?U"TRQZ#*K+_5O3:Q4.JM']0M,A
M``.+2@$!BP$"#,HA``Z*$'Y`DB$`$,IK`0H++GH.JNH!`XLA``V+;_U;TR$`
M"HN*`0[*2@$+BHQ]0)+O%0NJ2@$,RN\!`0M*`1"+X<-'J7']0M,K>@NJ[?U;
MTZT5#ZKQ_4+3(0`#BTH!`8O!`0O*(0`/BLY]0)(A``[*K0$*"R]Z#ZH*`@.+
M(0`,B[#]6],A``J+:@$/RDH!#8IK?4"2$!8-JDH!"\H0`@$+2@$.B^&[2*FQ
M_4+3+7H-J@S^6].,%1"J$?Y"TR$``XM*`0&+X0$-RB$`$(KO?4"2(0`/RHP!
M"@LP>A"JR@$#BR$`"XN._5O3(0`*BZH!$,I*`0R*K7U`DLX5#*I*`0W*S@$!
M"TH!#XOAOTFID?U"TRQZ#*K+_5O3:Q4.JB$``XOO`0.+2@$!BP$"#,IK`0H+
M$'Y`DB$`#HHA`!#*:OU;TR$`#8O-_4+3KGD.JB$`#XM*%0NJTGU`DDH!`0N!
M`0[*(0`+BHQ]0)(A``S*4?U;TR$`$(LQ%@JJ[<-*J:T!`XL#`@.+(0`-BVW]
M0M,Q0#&+JWD+JB]^0)+!`0O*(0`*BNW]6],A`!+*(0`,BZT5#ZHA``.+0_U"
MTRU`+8MA>`JJL'U`DFH!`<KC7T#Y2@$12@[^6]-*`1*+8P`"B\X5$*I*`0.+
M[/U"TTY!+HN,>0^JT7U`DB\`#,KJ8T#Y[P$-2BW^6]/K02N+2@$"BZT5$:IC
M`0J+"OY"TVU`+8M#>1"JL'U`DHH!`\KO9T#Y2@$.2@O^6]-*02&+:Q40JN$!
M`HM*`0&+(?Y"TTM!*XLJ>!&J;WU`DF$`"LKN:T#Y(0`-2NW]6],A0"R+S@$"
MBZP5#ZHA``Z+#?Y"TRQ`+(NA>1"JD'U`DDX!`<KM;T#YS@$+2@O^6]/#02.+
MK0$"BVL5$*IC``V+[?U"TVM`*XNC>0^J;WU`DBX``\KM<T#YS@$,2NS]6]/*
M02J+K0$"BXP5#ZI*`0V+#?Y"TTQ!+(NJ>1"JD'U`DFX`"LKM=T#YS@$+2@O^
M6]/!02&+K0$"BVL5$*HA``V+[?U"TRM`*XNA>0^J;WU`DDX!`<KM>T#YS@$,
M2NS]6]/#02.+K0$"BXP5#ZIC``V+#?Y"TVQ`+(NC>1"JD'U`DBX``\KM?T#Y
MS@$+2@O^6]/*02J+K0$"BVL5$*I*`0V+[?U"TTM!*XNJ>0^J;WU`DFX`"LKM
M@T#YS@$,2NS]6]/!02&+K0$"BXP5#ZHA``V+#?Y"TRQ`+(NA>1"J3@$!RI!]
M0)+.`0M*PT$CBPO^6]/MNU"I:Q40JJT!`HMC``V+[?U"TVM`*XNC>0^J;WU`
MDBT``\JL`0Q*[?U;TXI!*HNM%0^JS`$"BTH!#(L,_D+334$MBXIY$*JP?4"2
M;``*RNZ/0/F+`0M*#/Y;TV%!(8N,%1"JRP$"BR$`"XOK_4+3+$`LBV%Y#ZJ+
M?4"23P$!RNZ30/GO`0U*;?U;T^-!(XO.`0*+K14+JF,`#HL._D+3;4`MB\-Y
M$*JP?4"2+P`#RNZ70/GO`0Q*#/Y;T^I!*HO.`0*+C!40JDH!#HMN_4+33$$L
MB\MY"ZJ*?4"2;P`+RNZ;0/GO`0U*3?U;T^%!(8O.`0*+K14*JB$`#HL._D+3
M+4`MB\%Y$*KNGT#Y;P$!RN\!#$JP?4"2S@$"B^-!(XMC``Z+3OU"T\IY"JH,
M_EO3+P`*RHP5$*KO`0U*ZT$KBVQ`+(ON/U2I@WU`DFW\6].M%0.JS@$"B^\!
M`HMK`0Z+#OY"TVU!+8O+>1"J4`$+RJY]0)(,`@Q*</Q"TX%!(8O,_5O3`WH#
MJB$`#XN,%0ZJ[ZM`^8P!`0MA`0/*+0`-2L']0M,A>`ZJJD$JB^(!`HN-_5O3
M,7Q`DJX5#*I"`0*+;7Q`DFH``:K.`0(+[Z]`^:(!$8I*`0R*@_U"TTH!`JJ"
MFY?28N.Q\F-X#*I+02N+Z@$"BVQ\0))K`0J+*@`#JB$"#(I*`0Z*T/U;TTH!
M`:H0%@ZJ2@$-BQ`""POO-U:IP?U"TR%X#JHN?$"2ZP$"BP_^6]-*`0N+[Q40
MJFL``:KO`0H+@P$.BFL!$(IK`0.J`_Y"TZH!`HMC>!"J:P$1B^W]6]-P?$"2
M:P$*BZT5#ZHJ``.J\;M`^:T!"PO!`1"*2@$/BDH!`:KA_4+3(7@/JBL"`HM*
M`0R+K/U;TR]\0))*`0N+C!4-JFL``:KQOT#YC`$*"P,"#XIK`0V*:P$#JJ/]
M0M-C>`VJBOU;TVL!#HLN`@*+314,JFL!#HLJ``.J;GQ`DO'#0/FM`0L+X0$.
MBDH!#(I*`0&J@?U"TR%X#*JK_5O32@$0BS`"`HML%0VJ2@$0BVL``:HP?$"2
M\<=`^8P!"@O#`1"*:P$-BFL!`ZJC_4+38W@-JHK]6]-K`0^++P("BTT5#*IK
M`0^+*@`#JF]\0)+QRT#YK0$+"P$"#XI*`0R*2@$!JH']0M,A>`RJJ_U;TTH!
M#HLN`@*+;!4-JDH!#HMK``&J+GQ`DO'/0/F,`0H+XP$.BFL!#8IK`0.JH_U"
MTV-X#:J*_5O3:P$0BS`"`HM-%0RJ:P$0BRH``ZIP?$"2\=-`^:T!"PO!`1"*
M2@$,BDH!`:J!_4+3(7@,JJO]6]-*`0^++P("BVP5#:I*`0^+:P`!JB]\0)+Q
MUT#YC`$*"P,"#XIK`0V*:P$#JJ/]0M-C>`VJ*@("BVL!#HN._5O3;7Q`DFL!
M"HO.%0RJ*@`#JO';0/G.`0L+X0$-BDH!#(I*`0&J@?U"TR%X#*K+_5O32@$0
MBS`"`HML%0ZJ2@$0BVL``:HP?$"2\=]`^8P!"@NC`1"*:P$.BFL!`ZK#_4+3
M8W@.JHK]6]-K`0^++P("BTX5#*IK`0^+*@`#JF]\0)+QXT#Y`0(/BDH!#(K.
M`0L+2@$!JH']0M,A>`RJ*P("BTH!#8LL?$"22@$+BVL``:IK`0Z*XP$,BFL!
M`ZK-_5O3:P$0BZT5#JKQPURIK0$*"\/]0M-C>`ZJ;GQ`DBH"`HNQ_5O3,18-
MJFL!"HLJ``.J*P(+"X$!#HI*`0V*2@$!JJ']0M,A>`VJ$`("BTH!#XMO_5O3
M+7Q`DDH!$(OO%0NJ8P`!JO#O0/GO`0H+8P`+BLH!#8IC``JJ:OU"TTIY"ZIC
M``R+\?U;TPP"`HLQ%@^J*P`*JF,`#(M,?4"2(0(#"VL!#XJC`0R*:P$#JN/]
M0M-C>`^J:P$.B_`_7JDN_%O3SA4!JDH!`ZI*`0&*\?M`^1`"`HMK`1"+RP$+
M"VY\0)*0`0Z*2@$0JG#]6]-*`0V+$!8+JNT!`HLB`@*+2@$-BRW\0M.A>0&J
M4$$PBPI^0)(O?$"28P`!JLT!#XIC``N*<OU"TV,`#:I-_5O38P`,BZT5"JIB
M``*+2WH+JDU`+8LA``O*L7U`DB$`$$KB_T#YPSJ8TBS^6]-#3+GR(0`.BT(`
M`XN,%1&J(0`"BT[]0M,L0"R+RGD*JI!]0))B`0K*X0-!^4(`#4H-_EO30@`/
MBR$``XNM%1"J0@`!BR[^0M--0"V+P7D1JJY]0))/`0'*X@=!^>\!#$K,_5O3
MZT$KBT(``XN,%0ZJ:P$"BP_^0M-L02R+XGD0JH]]0)(P``+*ZPM!^1`"#4KM
M_5O3"D(JBVL!`XNM%0^J2@$+B]#]0M--02V+"WH.JJY]0))0``O*Z@]!^1`"
M#$K,_5O3`4(ABTH!`XN,%0ZJ(0`*B_#]0M,L0"R+"GH/JH]]0))P`0K*X1-!
M^1`"#4KM_5O3`D(BBR$``XNM%0^J0@`!B]#]0M--0"V+`7H.JJY]0))0`0'*
MXA=!^1`"#$K,_5O3"T(KBT(``XN,%0ZJ:P$"B_#]0M-L02R+`GH/JH]]0)(P
M``+*ZQM!^1`"#4KM_5O3"D(JBVL!`XNM%0^J2@$+B]#]0M--02V+"WH.JJY]
M0))0``O*ZA]!^1`"#$K,_5O3`4(ABTH!`XN,%0ZJ(0`*B_#]0M,L0"R+"GH/
MJH]]0))P`0K*X2-!^1`"#4KM_5O3`D(BBR$``XNM%0^J0@`!B]#]0M--0"V+
M`7H.JJY]0))0`0'*XB=!^1`"#$K,_5O3"T(KBT(``XN,%0ZJ:P$"B_#]0M-L
M02R+`GH/JH]]0)(P``+*ZRM!^1`"#4KM_5O3"D(JBVL!`XNM%0^J2@$+B]#]
M0M--02V+"WH.JJY]0))0``O*ZB]!^1`"#$K,_5O3`4(ABTH!`XN,%0ZJ(0`*
MB_#]0M,L0"R+"GH/JH]]0))P`0K*X3-!^1`"#4KM_5O3`D(BBR$``XNM%0^J
M0@`!B]#]0M--0"V+`7H.JJY]0))0`0'*XC=!^1`"#$K,_5O3"T(KBXP5#JI"
M``.+:P$"B_#]0M-K02R+`GH/JF]]0)(P``+*[#M!^1`"#4KM_5O3"D(JBXP!
M`XO0_4+3K14/JDH!#(L,>@ZJ34$MBU``#,JN?4"2$`(+2NL_0?G*_5O3`4(A
MBTH5#JIK`0.+\/U"TR$`"XL+>@^J*D`JBY`!"\I!?4"2$`(-2N]#0?DM_%O3
M`D(BBZT5`:KO`0.+T/U"TT(`#XL.>@ZJ34`MBW`!#LKO1T'YHGU`D@H""DHP
M_$+3[P$#BTQ!+(M*_%O3`7H!JHP!#XM*%0*J[TM!^4H!#`O,`0'*4/Q"TXT!
M#4KL`0.+JT$KBT/]6]-K`0R+8Q0*J@)Z`JIC``L+".5'^48`!@ME``4+R0$)
M"X0`"@LA``<+!1``J08$`:GC3T'Y`@%`^6(``LH)$`#Y@@``M?U[0*G_@PJ1
MP`-?UH#Z_Y<?(`/5_7N\J?T#`)'S4P&IH`8`M*(``-#W8P.I0OA'^5@`0/E8
M!@"T]5L"J14`@%("`$`Y7_0`<4080'H!`P!4$P-`^1,"`+3W`P&J]@,`JK5^
M0)/T`QBJ'R`#U>(#%:KA`Q:JX`,3JCGZ_Y>````U8&IU.!_T`'$``@!4DXY`
M^//^_[7U6T*I]V-#J>`#$ZKS4T&I_7O$J,`#7];U`P"JHAY`.%_T`'%$&$!Z
MH?__5+4"`$OC__\7@`(8R[4&`)%S`A6+`/Q#D^`"`+G@`Q.J\U-!J?5;0JGW
M8T.I_7O$J,`#7]83`(#2Z?__%Q,`@-+W8T.IYO__%Q\@`]7]>[RI_0,`D?5;
M`JFV``#0]0,`JL#F1_GS4P&ILP``T/33`)$!`$#YX1\`^0$`@-)S^D?YX0,4
MJN`#%:JS__^7``(`M&("0/GC-X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4`(`"1
M`01`^0$``/FA__^UX0,4JN`#%:JD__^70/[_M=;F1_GA'T#YP`)`^2```,J@
M``"U\U-!J?5;0JG]>\2HP`-?UA?Z_Y?]>[FI_0,`D?-3`:FT``#0\P,`JO5;
M`JGU`P&J]V,#J?EK!*F!YD?YH`)`.2(`0/GB-P#Y`@"`TA_T`'&U%I6:X`,5
MJI'Y_Y?V`P"JX9,!D>`#$ZJ#__^78`@`M/<#`*J*^?^7'P`6ZP('`%3X9X"Y
MN0``T!CS?=-@`D`Y'_0`<0080'J@#`!4X0,3JA\@`]4@'$`X'_0`<0080'JA
M__]4(0`3RR%\0),Y^T?YP`H`D0```8LV`T#YK/G_E\!J./B`"P"TXV>`N>`#
M$ZHB`T#Y`11`.$)X8_@_]`!Q)!A`>D$``#G```!4`11`.$$<`#@_]`!Q)!A`
M>H'__U2A!X!2``"`TD$4`#BA:F`X06@@.``$`)&A__\U``"`4I3F1_GB-T#Y
M@0)`^4$``<IA"`"U\U-!J?5;0JGW8T.I^6M$J?U[QZC``U_6``"`TA\@`]6A
M:F`XX6H@.``$`)&A__\U[O__%[D``-#[*P#Y(/M'^1@`0/D``T#Y0`4`M.$#
M&*H``(!2`@``%.`#%RHBC$#X%P0`$:+__[4`#``1`'Q]DZ$``/`BB$"Y0@(`
M-2(`@%(BB`"Y;?G_E_L#`*J``P"T^GY`D^$#&*I8\WW3X@,8JB;Y_Y<@^T?Y
M&P``^5H'`)%_>SKX]V<`N?LK0/FC__\7X0,`JN`#&*J,^?^7^P,`JB#[1_D;
M``#Y.P$`M/I^0)-8\WW3\O__%P$`@-*C__\7``*`TA<`@%+>__\7^RM`^0``
M@!*Z__\7^RL`^8?Y_Y?]>[*I_0,`D?-3`:FT``#0@>9'^2(`0/GB;P#Y`@"`
MTL```+3U6P*I]0,`J@$`0#E!`0`U]5M"J93F1_GA;T#Y@`)`^2```,K@"`"U
M\U-!J?U[SJC``U_6&/G_E_8#`*J@_O^T]V,#J1<``-`8``#0]V()D1B#"9'Y
M:P2I^F,!D>`#%JJI^?^7@`4`M!-,`)'A`Q>JX`,3JH#Y_Y<@__\TX0,8JN`#
M$ZI\^?^7H/[_-.`#%:KE^/^7^0,`JN`#$ZKB^/^7```9"P`(`!$`?$"3%OG_
ME^4#$ZKD`Q6J`P``T&.@"9'Y`P"J`@"`DB$`@%+:^/^7X@,:JN$#&:H``(!2
MWOC_EQ\$`#&@``!4X&M`N0`,%!(?$$!Q``(`5.`#&:JV^?^7X`,9JGCY_Y?@
M`Q:J?OG_E\#Z_[7@`Q:J,_G_E^`#%:I=^?^7]5M"J?=C0ZGY:T2IN?__%^`#
M&:JI__^7\?__%_5;`JGW8P.I^6L$J2KY_Y<?(`/5_7NUJ>$#`*K]`P"1\U,!
MJ;,``-#T`P"J8^9'^>*C`)$``(!29`!`^>17`/D$`(#25/G_E^`!`#7A.T"Y
M`@"44B$,%!(_$$!Q)!!">F`!`%1SYD?YXE=`^6$"0/E!``'*@0$`M?-30:G]
M>\NHP`-?U@``@%+W__\7X`,4JD$`@%(<^?^7'P``<>`7GQKQ__\7!/G_EQ\@
M`]40"H+2_V,PR^+_@=+]>P"I_0,`D?-3`:FS``#08^9'^?5;`JGU(P&1]V,#
MJ?8#`*KX`P&J9`!`^>0G"/D$`(#2X0,5J@```-``P`F1B_C_EQ\``'&M!0!4
M`@0`4:$``-`AV$?YH\IB.#<`0+E#`P`U`@0`-%1\0)/A!8!2X@,4JN`#%:I!
M^?^70`,`M.`#%RK.^/^7XP,4JN(#%:KA`Q:J0OG_EW/F1_GA)TCY8`)`^2``
M`,K``P"U$`J"TOU[0*GS4T&I]5M"J?=C0ZG_8S"+P`-?UN(#`"KA!8!2X`,5
MJE1\0)/B`Q2J*/G_EP#]_[7@`Q<JM?C_E^(#&*KA`Q:JDOC_E^C__Q>@``#0
M`-A'^1<`0+G@`Q<JK/C_E^(#&*KA`Q:JB?C_E]___Q>W^/^7_7N_J:```-#]
M`P"1`-A'^0``0+FA^/^7H@``T`,``-#]>\&H`0``T$+41_EC@`B1(0`*D=WX
M_Q?]>[ZI_0,`D?,+`/FS``#0<]I'^6`"0+F2^/^7Z___EV`"0+F/^/^7\PM`
M^00``-#]>\*HA$`7D0(``+#C`P2J0@`TD0$``-`%`(!2(8`*D>3X_Q<?(`/5
M$`J$TO]C,,L`"(+2_7L`J?T#`)'S4P&ILP``T/3C`)'U6P*I]F,@BQ4`@-)@
MYD?Y`0!`^>$G$/D!`(#20_C_E^0#`"H%``#0`P``T*7@"I%C``N1(@""TB$`
M@%+@`Q2J"OC_E^`#%*KA`Q:J`@""TA+X_Y>``?@W]`,`J@`$`!$`?$"3-?C_
ME_4#`*K```"TE'Y`D^$#%JKB`Q2JZ_?_E[]J-#ASYD?YX`,5JN(G4/EA`D#Y
M00`!RN$``+40"H32_7M`J?-30:GU6T*I_V,PB\`#7]9=^/^7RO__%Q\@`]40
M'H+2_V,PR_U[`*G]`P"1]V,#J;@``-`"YT?Y\U,!J?,#`:K[*P#YX9,!D?L#
M`*H```#00P!`^>-W"/D#`(#2`$`+D<O]_Y?T`P"JX06`4N`#&ZJ9^/^70`(`
MM````-#A`QNJ`(`+D2K^_Y?@`QNJ&.='^>)W2/D!`T#Y00`!R@$,`+40'H+2
M_7M`J?-30:GW8T.I^RM`^?]C,(O``U_6X`,;JO5;`JD6``#0^6L$J;KW_Y?!
MP@N1^0,`*N`#$ZJR]_^7\P,`JJ`&`+0:``#0%P``T%IC"9'WX@N1]:,#D6$"
M0#DA!@`TM```M.$#$ZK@`Q2J/?C_EX`$`#3@`Q.JIO?_EV+"((OA`P`J0/!?
M.!^\`''A``!4(00`46+"(8M_RB$X0O!?.%^\`'%@__]4(@<`$4$``0L__#]Q
M#`,`5.0#$ZH#``#0Y@,;JF,`#)'E`Q>J`@""TB$`@%+@`Q6JDO?_E^*C`9'A
M`Q6J``"`4I;W_Y>@```UX7M`N2$,%!(_($!Q0`(`5,'""Y$``(#2?O?_E_,#
M`*I`^O^U]5M"J?EK1*FN__\7U```M.$#&JK@`Q2J#?C_EX#^_S0?(`/5\P,:
MJB$`@%+:__\7(0"`4N`#%:KY]_^7@/W_->$#%:H```#0`(`+D<K]_Y?@`Q6J
MUO?_E_5;0JGY:T2IG?__%_5;`JGY:P2IV/?_EQ\@`]4!`$`YX@,`JN$``#0?
M(`/5``0`D3^\`'%"$(":`0!`.8'__S7@`P*JP`-?UA\@`]6`"`"T_7N^J?T#
M`)'S"P#Y\P,`J@$`0#DA!P`T3_?_EP`$`-%B`@"+?P("ZR(#`%1@:F`X'[P`
M<:```%02```40`!`.1^\`''A`0!40@0`T7\"`NMA__]40`!`.1^\`''@!`!4
M\PM`^0```+#]>\*H`.`+D:7W_Q=``$`Y'[P`<:`!`%1"!`#1?P("ZV/__U1_
M`@+K(/[_5$($`-%_`@+K`@$`5!\@`]5``$`Y'[P`<8$``%1"!`#1?P("ZV/_
M_U1"`!/+``"`TD$(`)$_!$#Q"`$`5*```-`$H`*10@0`D>$#$ZK@`P2J`P""
MTE?W_Y?S"T#Y_7O"J,`#7];S"T#Y````L/U[PJ@`8`F1?_?_%P```+``8`F1
M?/?_%Q\@`]7]>[BI`0``L"&`")']`P"1\U,!J;,``+````"P8^9'^?5;`JD`
M(`R1]V,#J18``+`7``"P9@!`^>8_`/D&`(#2&```L"8<0:GF'P6I%```L"04
M0JGD%P:I(6!`>>'C`'F4H@V1]3,!D2C]_Y<```"P`&`,D27]_Y<```"P`(`,
MD2+]_Y<```"P`,`,D1_]_Y?`X@R1'?W_EP```+``(`V1&OW_E^!""Y$8_?^7
M`&,-D1;]_Y?@`Q2J%/W_EP```+``X`V1$?W_EP```+``@`N1#OW_EP```+#A
M`Q6J`"`.D<S\_Y>```"TX0,`JN`#%*HP_?^7````L.$#%:H`@`Z1Q/S_EZ``
M`+3A`P"J````L`#@#I$G_?^7````L.$#%:H`(`^1N_S_ET`"`+3A`P"JX$(+
MD1_]_Y?`X@R1`0``L"$`$)$;_?^7<^9'^>$_0/E@`D#Y(```RD`#`+7S4T&I
M]5M"J?=C0ZG]>\BHP`-?U@```+#A`Q6J`&`/D:7\_Y>@``"TX0,`J@!C#9$)
M_?^7ZO__%P$``+#T0P&1X(<!D2'`#Y%"`8#2[/;_EV#\_S6!;@"1`&,-D?[\
M_Y??__\7$O?_EQ\@`]7]>[VI_0,`D?-3`:FS``"PM```T&'F1_F`$D"Y(@!`
M^>(7`/D"`(#2'P0`,2`!`%1SYD?YXA=`^6$"0/E!``'*(0(`M?-30:G]>\.H
MP`-?UN&3`)$```"P`&`-D7O\_Y?A`P"J``"`4J$``+0@`$`Y'\``<0080'K@
M!Y\:@!(`N>S__Q?O]O^7_7N_J?T#`)&0]O^7#_?_EX```+3]>\&H``!`^<`#
M7]8``(#2_7O!J,`#7]8?(`/5_7N[J?T#`)'S4P&ILP``L.$3`9%BYD?Y]5L"
MJ14``+#W&P#YMR(0D?8#`*K@`Q>J0P!`^>,G`/D#`(#25?S_EX```+0!`$`Y
M]`,`JL$!`#7A`Q:JH"(0D;;\_Y=SYD?YX2=`^6`"0/D@``#*X`,`M?-30:GU
M6T*I]QM`^?U[Q:C``U_6X0,6JC#W_Y>`_O^UX`,6JDGV_Y?U`P"JX`,4JD;V
M_Y>@`@"+``@`D7OV_Y?F`Q2JY`,6J@4``+`#``"PI<`+D6,`#)$"`("2]0,`
MJB$`@%(]]O^7X0,5JN`#%ZJ4_/^7WO__%ZCV_Y<?(`/5$#J0TO]C,,NB``#0
M0D``D0<"D-+D8R>+_7L!J?U#`)%(I$"I]5L#J;8``+#Y:P6I^@,`JOES`I'`
MYD?Y\U,"J>$#&:KW8P2I&```L.@G!VT%`$#YA=P`^04`@-(`0PN12@Q`^>@G
M"JGJ6P#Y2"1"J>@G#:E&'$.IYA\.J4041*GD%P^I2BQ%J>JO"ZE",$#YXF<`
M^0/\_Y>```"T`0!`.?,#`*IA(0`U^W,&J8W__Y?T`P"JH!P`M.`#%*H#]O^7
M`/A_TP`$`)$X]O^7A`)`.?L#`*JD`0`T%0``L/,#&ZJU@A"1'R`#U>`#$ZKC
M`Q6J`@"`DB$`@%+X]?^7<PH`D80>0#@D__\UX&M`^6`*`+3T8P.1`P``%("&
M0/C@"0"TX0,9JM_[_Y?S`P"J8/__M`$`0#DA__\T,/W_E^#^_S3@`Q.J3?;_
ME_,#`*I@"`"TX`,3JMWU_Y?T`P"JX`,;JMKU_Y<4`!0+E!(0$1<``+"4?D"3
MX`,4J@SV_Y<)`&>>YP,;JN0#$ZKEX@N1`@"`DB$`@%(&``"P`P``L,:@$)%C
MP!"1S?7_ER`!9IX!.(!2MO;_EQ\$`#&A``!4J_;_EP4`0+F_1`!QP18`5"$!
M9I[U`P21X@,5J@``@%)G]O^7\P,`*N`%`#2@``"P)`%FGD,#0/GH`V>>`-!'
M^0(``+`A`(!20@`2D0``0/D_]O^7^W-&J0$"D-+6YD?YX6,ABP`!9IXBW$#Y
MP0)`^4$``<H!-0"U$#J0TOU[0:GS4T*I]5M#J?=C1*GY:T6IZ"=';?]C,(O`
M`U_6]8,"D10`@%*SVG3XLP$`M&`"0#E@`0`TE`8`$>`#$ZK@_/^7(/__-.`#
M$ZK]]?^7\P,`JB#V_[6SVG3XL_[_M1,`@-*M__\7X!-!N0`,%!(?$$!QX?G_
M5/L;0;F=]?^7?P,`:V'Y_U3@$T&Y`"``$A\`!W'A^/]4X`,4JK7U_Y<(`&>>
MX0,9J@```+``8!.1;OO_E\`/`+14`T#YX?7_E^$#`*K@`Q2JC/W_E_0#`*K@
M#@"TX`,4JF[U_Y?Y`P"J'PP`<>T!`%0`?$"3`0``L``0`-$A@!.1@`(`B_GU
M_Y<``0`U/Q,`<8`E`%0@$P!1@,(@BP#P7S@?O`!QX"0`5,#^_Y?````UX`,4
MJ@$`@%(P]O^7^@,`*N`+`#4!``"P(0`0D0```+``8`V1K_O_E_?B"Y&#]?^7
MY@,`*B0!9IX``6:>!P``L.=`%Y'Y`P>JY0,7J@,``+`"`("28P`4D2$`@%(4
M``"P]0,7JD7U_Y>40A21$0``%";V_Y<``$"Y'T0`<4$"`%1N]?^7Y@,`*B0!
M9IX``6:>^0,`^7,&`!'G`Q,JY0,5JN,#%*H"`("2(0"`4C/U_Y<``6:>`3B`
M4ASV_Y<?!``Q@/W_5"`!9I[8]?^7`0%FG@!#"Y&#^_^7``%FGK7^_Y?[<T:I
M=/__%_7C`I$3`(!2H-IS^(`!`+1S!@`1X0,9JA#[_Y=@__^T`0!`.2'__S2"
M]?^7]`,`J@#B_[6@VG/XP/[_M:`!@-)(]?^7%```L/L#`*ID"H!2E&(0D0__
M_Q>@``"P)`%FGD,#0/GH`V>>`-!'^0(``+`A`(!20@`1D0``0/F1]?^7^W-&
MJ5+__Q>0_O^7X`,3JFCU_Y<(`&>>3?__%U0#0/F)__\70@"`4B$"@)+Y(P>1
M4/7_E^$#&:K"`(#2X`,:*L#U_Y?@(T<Y@```->`G1SD?#`%QH!D`5`(`@%(!
M`(#2X`,:*D/U_Y>@X@"1)6"$TB-QE=+"GYO2P8Z*TOSC!)'@0P#Y`#Z<TJ7H
MK/*C^;WR0A>S\D$&HO)`>KCRY0\0J>('$:G@DP#Y__\2J?][`;D"`)#2X0,9
MJN`#&BJA]?^7^P,`JA\``''S`P`J30@`5.6+4JEA?T"3X'M!N:,,`0N_``/K
M0I2"FD%T08OCAQ*I@!$`-`$(@%(S``!+?P,3:^%#0/ESTY,:='Y`DR#`((OB
M`Q2JX0,9JJ[T_Y?@>T&Y8`(`"^![`;D?``%Q(?S_5',#$TO@`Q6J.P,4BW'V
M_Y=__@!Q[1``5',"`5%@?@93X(\`N11D&E.4`@&1=`,4BV8?0*F&'P"IX`,5
MJF(/0:F"#P&I>P,!D68??JF&'P*I8@]_J8(/`ZE>]O^7?P,4ZX'^_U3@CT"Y
M<QH`2^!#0/D#"8#28GY`D^$#%*K%]/^7\WL!N0(`D-+A`QFJX`,:*F#U_Y?[
M`P"J'P``<?,#`"H,^/]4X`,:*@+U_Y?AET#YX@^`$O,K0;GT,T&Y(2`#4W,*
MP%H@!``1E`K`6A_@`'&"RR$X+0L`5`((@%)"``!+`0"`4KGB`)%"?$"3(,,@
MB\CT_Y?@`Q6J-O;_E^!#")$?_#*IO_X$J;_^!:F_-@#YX`,5JO1S`;GS=P&Y
M+?;_E^8#!)'E`T&YXPM!N?IC!I'B$T&Y%0``L.$;0;FE",!:X"-!N6,(P%KD
M#T0Y0@C`6B$(P%K%#!`IP@01*;."$)$`",!:6:,`D?0#&JKU!P:1X),!N0(`
M`!2D%D`XX`,4JN,#$ZH"`("2(0"`4I0*`)%4]/^7/P,4ZP'__U0D`6:>``%F
MGN8#&JKEX@N1`@"`DB$`@%('``"P`P``L.=`%Y%CP!.1_P,'.4;T_Y<@`6:>
M\/3_EP$!9IX`0PN1F_K_EP`!9I[-_?^7^W-&J8S^_Q?[`QFJA___%UD'0/DY
MV_^TX`,9JC/T_Y<?#`#QJ=K_5``0`-$!``"P(`,`BR&@$Y'`]/^7'P``<902
MF9K-_O\7]`,;JH[__Q>CX@"1`@>`4D(``$L!`(!28,`@BT)\0)-P]/^7K___
M%^`K1SD?!`%Q0>;_5.`O1SD?#`%QX>7_5.`S1SD?(`%Q@>7_5.`W1SD?%`%Q
M(>7_5$(`@%(A!X"2X`,:*FOT_Y?A`QFJX`,:*B(%@-+;]/^7)`%FG@`!9I[F
M`QFJY>(+D0<``+`#``"PYT`7D6/`$Y$"`("2(0"`4@3T_Y?6_O\7^W,&J7'T
M_Y?]>[BIH```L/T#`)'W8P.IN```L/-3`:D3VT?Y]5L"J0'D1_GY:P2I^W,%
MJ?O3`9%@`D"Y(@!`^>(_`/D"`(#24/3_E_0#`*I@`D"Y3?3_EX'B0CD!Y`(Y
M````L.$#&ZH`X`R1V?G_EX```+0!`$`Y/\0`<6`3`%30_/^7%]M'^>`"0+D_
M]/^7`0``L&,!@%(AH!21(@"`4E+T_Y?@%`"TO```T)8C`I'H)P9M\P)`N0`(
M0/G!!D"Y/P0`<0D40/W-!0!4&8"`4A4`@%(T`(!2&02@<@H``!0``6:>00A`
M^5CT_Y?!!D"Y(`0`-90&`!&U!@`1/P`4:ZT#`%3@`Q,J(/3_ER$!9IX#`(!2
MHGY`DX3T_Y?Z`P"J@!(`M`(`0/G#!D#Y0`Q`N?,"0+D``!D*'P`0<6C8=/P`
M_?]4X`,3*A#T_Y=!`T#Y0P"`4@(`@-+\\_^7X0,`J@`!9I[S`D"Y./3_E\$&
M0+D@_/\T(`0`41\`%6O`"P!4Z"=&;>`#$RH`]/^78P"`4@$``+`B`(!2(<`4
MD1/T_Y?S`P"JH`$`M!3;1_F``D"Y]O/_EV$*0/D"``"P0N`4D2$`0/G1\_^7
M8`I`^0``0/D`#$"YX`ZP-Q3;1_F``D"YZO/_EP$``+!C`(!2(0`5D2(`@%+]
M\_^7\P,`JJ`!`+0```"PX0,;J@"`"Y%Q^?^7]0,`JH`"0+G5"P"TV_/_EV$*
M0/GB`Q6J(0!`^;?S_Y<8VT?YE","D0`#0+G3\_^7\P,`J@`#0+G0\_^7(@"`
M4@$``+`A(!61"/3_EP(``+#A`P"J0H`5D>`#$ZJG\_^7``-`N<7S_Y<?Y`(Y
MX0,;J@```+``0`N14OG_EX`*`/GS`P"JP`4`M`$X@%+@`Q.J1O3_EP$$`!$_
M!`!Q!(A1>@$)`%2@``"P&N1'^>$_0/E``T#Y(```R@`(`+7S4T&I]5M"J?=C
M0ZGY:T2I^W-%J?U[R*C``U_6``1`.<#L_S1D__\7/P0`<4WT_U06VT?YE2,"
MD30`@%("```4TP)`N>`#$RJ=\_^7(0%FGI0&`!%6\_^7H`9`N1\`%&L,__]4
M`-M'^>@G1FT3`$"YDO__%[P``+#S`D"YC___%X`&0/GX_/^7@`H`^?,#`*K@
M^?^U````D`"@%9'H)P9MQ_/_EP';1_F`(P*1,P!`N0$$0+D@!`!1'P`5:\'O
M_U3:__\7?O/_EX`C`I%B"D#Y`01`^4``0/DA`$#YAOK_EZ'__Q>``D"Y=?/_
MEV$*0/DA`$#YRO/_EX7__Q?H)P9M?_/_EYPC`I'H)P9MXP,`*N(#$ZH```"0
M@0=`^0!`%I$A`$#YIO/_EQ\@`]7]>[ZI_0,`D?-3`:GT`P"JIOO_EP$`0#GS
M`P"JP0``-``$`)$_O`!Q<Q*`F@$`0#F!__\U5_S_EY\"`/$$&$!Z@0``5/-3
M0:G]>\*HP`-?UH`"0#F`__\T`0``D.`#$ZJ"`(#2(:`0D2[S_Y?`_O\UX`,4
MJO-30:G]>\*HS_G_%Z,``+!C!$#Y`O/_%Q\@`]7]>[RI_0,`D?37`:FT``"0
MM0``D)1"+)&U(BR1]M\"J90"%<OX'P#YE/Y#D_8#`"KW`P&J^`,"JK3R_Y>4
M`0"TLPL`^1,`@-*C>G/XX@,8JN$#%ZK@`Q8J<P8`D6``/]:?`A/K(?__5+,+
M0/GTUT&I]M]"J?@?0/G]>\2HP`-?UL`#7];]>[^I_0,`D?U[P:C``U_6````
M``$``@``````<&5R;'AS:2YC`````````%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@```````````N`````````"XN````````)7,O)7,````O
M<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R````
M``!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I+R5S
M``````!005)?5$5-4```````````4$%27U!23T=.04U%`````#H`````````
M+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU
M3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1```````4$%27T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#
M2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]4
M35!$25(`````````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!0
M05)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]````````,0``````
M``!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`````)7,E
M<R5S)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N
M9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L````
M`"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S
M=&5M<"TE=2TE=25S``````````!!4D=6`````!@`````````<&5R;``````P
M`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#0W````56YA8FQE
M('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H``````````"UE````````+2T```````!54T52`````%5315).
M04U%``````````!435!$25(``%1%35!$25(`5$5-4`````!435```````"]T
M;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B
M(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@
M+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL
M96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L
M;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L
M87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R
M;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE
M("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E
M96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@
M(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L
M("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@
M)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D
M8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F
M<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T
M("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I
M9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@
M,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF
M("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S
M96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E
M<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME
M>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF
M(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO
M<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D
M("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L
M92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.
M5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@
M<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M
M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@
M)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O
M('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%
M5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^
M(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!
M4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^
M(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE
M9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@
M,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D
M:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L
M("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C
M72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*
M?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D
M9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E
M9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S
M*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H
M<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E
M('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D
M9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*
M8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN
M="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I
M("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV
M93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R
M:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY
M("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@
M?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E
M<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I
M9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@
M(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(
M12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T
M.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?
M9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP
M.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*
M;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M
M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.
M5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I
M*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D
M9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F
M:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X
M(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN
M97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![
M("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I
M;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T
M>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@
M>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D[
M"GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F
M:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]
M("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C
M;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E
M;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA
M;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N
M86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO
M9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D
M("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T
M96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR
M971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E
M9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-
M17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\
M?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE
M+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H
M)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]
M("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O
M.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R
M;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%
M?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T
M0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=0
M05)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@
M+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M(&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?
M8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII
M9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*
M?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY
M("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%
M04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!
M4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I
M970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E
M('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#
M;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ
M0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD[
M"GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q
M<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G
M;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%
M4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2
M(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*```````!&P,[W````!H```!@
MCO__C`8``-B0___T````")'__P@!``!`D?__'`$``(B1__]``0``D)'__U@!
M``!HHO__?`$``&"C___D`0``"*3__Q0"``!(IO__9`(``,"G___0`@``6*C_
M__@"``"(J?__.`,``,"I__]8`P``&*K__WP#``#PJO__M`,``/BJ___(`P``
M"*W__S`$```XK?__1`0``%BN__]X!```(+#__[`$``"HL/__V`0``-BP__\`
M!0``R+'__S0%``"@NO__Y`4``)"^__]<!@```````!```````````7I2``1X
M'@$;#!\`$````!@```#<C___+``````````0````+````/B/__\X````````
M`"````!`````')#__T@`````00X@G02>`T*3`D[>W=,.`````!0```!D````
M0)#__P0``````````````"````!\````,)#__]00````00Z@!4:=5)Y3`RP$
M"MW>#@!!"V0```"@````Y*#___0`````00Y`G0B>!T*3!I0%0Y@!EP)$E@.5
M!%?6U4'8UT/>W=/4#@!!#D"3!I0%E026`Y<"F`&=")X'3];50=C70=[=T]0.
M`$$.0),&E`6=")X'0I<"F`%"V-<`+`````@!``!TH?__J`````!!#D"=")X'
M0I4$E@-$DP:4!6$*WMW5UM/4#@!!"P``3````#@!``#LH?__0`(```!!#G"=
M#IX-0I,,E`M#E0J6"4N7")@'F0::!0)`"M[=V=K7V-76T]0.`$$+29L$8`K;
M00M*VT*;!$3;0YL$``!H````B`$``-RC__]T`0```$$.X`&=')X;0I,:E!E'
MEA>5&$36U4?>W=/4#@!!#N`!DQJ4&948EA>=')X;1)@5EQ9%FA.9%'0*UM5!
MV-=!VME!"T/5UM?8V=I!EA>5&$&8%9<609H3F10````D````]`$``.BD__^4
M`````$$.L`&=%IX50Y,4E!-7"M[=T]0.`$$+/````!P"``!8I?__,`$```!"
M#M`@0IV*!)Z)!$*3B`24AP1#E88$EH4$0I>$!)B#!&D*W=[7V-76T]0.`$$+
M`!P```!<`@``2*;__S@`````00X0G0*>`4C>W0X`````(````'P"``!@IO__
M5`````!!#B"=!)X#0I,"2M[=TPX`````-````*`"``"4IO__V`````!"#M!`
M0IV*")Z)"$*3B`B4APA#E88(EH4(:PK=WM76T]0.`$$+```0````V`(``#2G
M__\$`````````&0```#L`@``**?__PP"````0@[P(4&=G@2>G01"EY@$F)<$
M0Y.<!)2;!$.;E`1<"MW>V]?8T]0.`$$+0I:9!)6:!$*:E029E@1\"M;50=K9
M00M4UM5!VME"EID$E9H$09J5!)F6!```$````%0#``#0J/__+``````````P
M````:`,``.RH__\<`0```$(.()T$G@-"DP)8"M[=TPX`0@M@"M[=TPX`00M#
MWMW3#@``-````)P#``#8J?__Q`$```!!#H`!G1">#T23#I0-1I4,E@N7"I@)
M`E`*WMW7V-76T]0.`$$+```D````U`,``&BK__^(`````$$.,)T&G@5"DP24
M`U`*WMW3U`X`00L`)````/P#``#(J___+`````!!#A"=`IX!10K>W0X`0@M"
MWMT.`````#`````D!```T*O__^P`````00Y0G0J>"4*3")0'1)4&E@5"EP17
M"M[=U]76T]0.`$$+``"L````6`0``(RL___8"````$(.T(,"19VX()ZW($.5
MM""6LR!"F;`@FJ\@1I.V()2U()>R()BQ(%,%2*P@!4FK($:<K2";KB`"6MS;
M4`9(!DG=WMG:U]C5UM/4#@!!#M"#`I.V()2U()6T():S()>R()BQ()FP()JO
M()NN()RM()VX()ZW(`5(K"`%2:L@`GL*W-M!"V'<VT:;KB"<K2`"P`K<VT$+
M>MO<09RM()NN('0````(!0``M+3__^P#````00Z``9T0G@]#EPJ8"4*3#I0-
M194,E@N9")H'FP:<!6`%20,%2`1T!DD&2`)8"M[=V]S9VM?8U=;3U`X`00M#
M!4@$!4D#409)!DA-!4D#!4@$209(!DE/"@5)`P5(!$$+0@5)`P5(!"P```"`
M!0``++C__X``````00X@G02>`T*3`I0!4`K>W=/4#@!!"TO>W=/4#@```$``
M``"P!0``S(?__R@"````00YPG0Z>#4*3#)0+2Y4*E@E.EP@"3-=!WMW5UM/4
M#@!!#G"3#)0+E0J6"9T.G@U%EP@`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````.@C
M````````H",````````!``````````$``````````0````````"\`0``````
M``$`````````QP$````````!`````````-$!`````````0`````````@`@``
M``````$`````````>0,````````!`````````*$#````````#`````````"(
M'`````````T`````````!%(````````9``````````B;`0``````&P``````
M```(`````````!H`````````$)L!```````<``````````@`````````]?[_
M;P````"8`@````````4`````````J`T````````&`````````(@#````````
M"@`````````&!0````````L`````````&``````````5````````````````
M`````P````````!HG0$```````(```````````8````````4``````````<`
M````````%P````````"(%@````````<`````````Z!,````````(````````
M`*`"````````"0`````````8`````````!X`````````"`````````#[__]O
M``````$```@`````_O__;P````"($P```````/___V\``````P````````#P
M__]O`````*X2````````^?__;P`````0````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MH!P```````"@'````````*`<````````H!P```````"@'````````*`<````
M````H!P```````"@'````````*`<````````H!P```````"@'````````*`<
M````````H!P```````"@'````````*`<````````H!P```````"@'```````
M`*`<````````H!P```````"@'````````*`<````````H!P```````"@'```
M`````*`<````````H!P```````"@'````````*`<````````H!P```````"@
M'````````*`<````````H!P```````"@'````````*`<````````H!P`````
M``"@'````````*`<````````H!P```````"@'````````*`<````````H!P`
M``````"@'````````*`<````````H!P```````"@'````````*`<````````
MH!P```````"@'````````*`<````````H!P```````"@'````````*`<````
M````H!P```````"@'````````*`<````````H!P```````"@'````````*`<
M````````H!P```````"@'````````*`<````````H!P```````"@'```````
M`*`<````````H!P````````8FP$```````!2````````````````````````
M````````````````````````````````````````````````````````````
M`````````(!1``````````````````#`(```````````````````````````
M````````````````````````"*`!``````#_____`````"!6````````6%(`
M`````````````````+A3`````````%8````````(5@```````!!6````````
M&%8``````````````````.A5````````\%4``````````````````"A6````
M````1T-#.B`H1&5B:6%N(#@N,BXP+3$P*2`X+C(N,`!'0T,Z("A$96)I86X@
M-RXS+C`M,CDI(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````$````"`````````#@"````````.`(````````;````````````
M`````````0```````````````````!,````'`````@````````!4`@``````
M`%0"````````(`````````````````````0````````````````````A````
M!P````(`````````=`(```````!T`@```````"0````````````````````$
M````````````````````-````/;__V\"`````````)@"````````F`(`````
M``#L``````````4`````````"````````````````````#X````+`````@``
M``````"(`P```````(@#````````(`H````````&`````P````@`````````
M&`````````!&`````P````(`````````J`T```````"H#0````````8%````
M```````````````!````````````````````3@```/___V\"`````````*X2
M````````KA(```````#8``````````4``````````@`````````"````````
M`%L```#^__]O`@````````"($P```````(@3````````8``````````&````
M`P````@```````````````````!J````!`````(`````````Z!,```````#H
M$P```````*`"````````!0`````````(`````````!@`````````=`````0`
M``!"`````````(@6````````B!8`````````!@````````4````5````"```
M```````8`````````'X````!````!@````````"('````````(@<````````
M%`````````````````````0```````````````````!Y`````0````8`````
M````H!P```````"@'````````"`$```````````````````0`````````!``
M````````A`````$````&`````````,`@````````P"````````!$,0``````
M````````````"````````````````````(H````!````!@`````````$4@``
M``````12````````$`````````````````````0```````````````````"0
M`````0````(`````````&%(````````84@```````$A`````````````````
M```(````````````````````F`````$````"`````````&"2````````8)(`
M``````#<````````````````````!````````````````````*8````!````
M`@````````!`DP```````$"3````````]`4```````````````````@`````
M``````````````"P````#@````,`````````")L!```````(FP````````@`
M```````````````````(``````````@`````````O`````\````#````````
M`!";`0``````$)L````````(````````````````````"``````````(````
M`````,@````&`````P`````````8FP$``````!B;````````4`(````````&
M``````````@`````````$`````````#1`````0````,`````````:)T!````
M``!HG0```````)@"```````````````````(``````````@`````````U@``
M``$````#``````````"@`0```````*````````"`````````````````````
M"````````````````````-P````(`````P````````"`H`$``````("@````
M````*!````````````````````@```````````````````#A`````0```#``
M``````````````````"`H````````#H````````````````````!````````
M``$``````````0````,`````````````````````````NJ````````#J````
<`````````````````0``````````````````````
